--[[
Spezialisierung zum rendern der Anzahl von verbleibenden Ballen für Folie und Garn auf den Bildschirm.

Author:	Ifko[nator]
Datum:	18.09.2015

Version:	v1.0
History:	v1.0 @ 18.09.2015 - initial implementation
]]

KroneUltimaExtension = {};

local kroneUltimaExtension_directory = g_currentModDirectory;

function KroneUltimaExtension.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Ultima, specializations);
end;

function KroneUltimaExtension:load(xmlFile)

	if self.baleCounterClackBackGroundImg ~= nil then
		self.hudPosYStart = 0.295;
		self.hudPosYOffSet = 0.168;
	else
		self.hudPosYStart = 0.29;
		self.hudPosYOffSet = 0.173;
	end;
	
	self.hudPosY = self.hudPosYStart;
	self.hudWidth = 0.0335;
	self.hudHeight = 0.045;
	
	self.hudFoilPosX = 0.826;
	self.hudNetPosX = 0.915;
	self.hudBackgroundPosX = 0.855;
	
	self.hudBackgroundWidth = 0.15;
	
	self.hudOverlayFoilFilename = Utils.getFilename("baleFoil.dds", kroneUltimaExtension_directory);
	self.hudOverlayFoilCamOff = Overlay:new("hudOverlayFoilCamOff", self.hudOverlayFoilFilename, self.hudFoilPosX, self.hudPosY, self.hudWidth, self.hudHeight);
	self.hudOverlayFoilCamOn = Overlay:new("hudOverlayFoilCamOn", self.hudOverlayFoilFilename, self.hudFoilPosX, self.hudPosY + self.hudPosYOffSet, self.hudWidth, self.hudHeight);
	
	self.hudOverlayNetFilename = Utils.getFilename("baleNet.dds", kroneUltimaExtension_directory);
	self.hudOverlayNetCamOff = Overlay:new("hudOverlayNetCamOff", self.hudOverlayNetFilename, self.hudNetPosX, self.hudPosY, self.hudWidth, self.hudHeight);
	self.hudOverlayNetCamOn = Overlay:new("hudOverlayNetCamOn", self.hudOverlayNetFilename, self.hudNetPosX, self.hudPosY + self.hudPosYOffSet, self.hudWidth, self.hudHeight);
	
	self.hudOverlayBackgroundFilename = Utils.getFilename("background.dds", kroneUltimaExtension_directory);
	self.hudOverlayBackgroundCamOff = Overlay:new("hudOverlayBackgroundCamOff", self.hudOverlayBackgroundFilename, self.hudBackgroundPosX, self.hudPosY, self.hudBackgroundWidth, self.hudHeight);
	self.hudOverlayBackgroundCamOn = Overlay:new("hudOverlayBackgroundCamOn", self.hudOverlayBackgroundFilename, self.hudBackgroundPosX, self.hudPosY + self.hudPosYOffSet, self.hudBackgroundWidth, self.hudHeight);
end;

function KroneUltimaExtension:draw()
	if self:getIsActive() then
		if self.gui ~= nil and self.gui.baseElement ~= nil then
			if self.gui.baseElement.visibility then
				self.hudOverlayBackgroundCamOn:render();
				self.hudOverlayFoilCamOn:render();
				self.hudOverlayNetCamOn:render();
			
				self.hudPosY = 0.465;
			else
				self.hudOverlayBackgroundCamOff:render();
				self.hudOverlayFoilCamOff:render();
				self.hudOverlayNetCamOff:render();
				
				self.hudPosY = self.hudPosYStart;
			end;
		end;
	
		setTextAlignment(RenderText.ALIGN_CENTER);
		
		for foil = 1, #self.wrapperFoilHolders do
			local foilLength = self.wrapperFoilHolders[foil].remainingFoilLength * 2;
			local foilPerBale = self.baseFoilUsePerBale * self.baleSizes[self.baleSizeIndex].size;		
			local numLeftBalesFoil = math.ceil(foilLength / foilPerBale);
			
			if numLeftBalesFoil <= 5 then
				setTextColor(0.95, 0, 0, 1);
			else
				setTextColor(1, 1, 1, 1);
			end;
			
			renderText(self.hudFoilPosX + 0.06, self.hudPosY + 0.014, 0.028, "" .. numLeftBalesFoil);
		end;

		local netPerBale = self.numNetWraps * math.pi * self.baleSizes[self.baleSizeIndex].size;
		local numLeftBalesNet = math.ceil(self.netRoleTop.length / netPerBale);	
		
		if numLeftBalesNet <= 5 then
			setTextColor(0.95, 0, 0, 1);
		else
			setTextColor(1, 1, 1, 1);
		end;
		
		renderText(self.hudNetPosX + 0.06, self.hudPosY + 0.014, 0.028, "" .. numLeftBalesNet);
	end;
	
	setTextAlignment(RenderText.ALIGN_LEFT);
end;

function KroneUltimaExtension:delete()end;
function KroneUltimaExtension:mouseEvent(posX, posY, isDown, isUp, button)end;
function KroneUltimaExtension:keyEvent(unicode, sym, modifier, isDown)end;
function KroneUltimaExtension:update(dt)end;